@@ -5,17 +5,17 @@ use strict;
 use warnings;
 
 use Moose;
-use Module::Runtime qw( use_module );
+use Class::Load 0.20 qw(load_class);
 use MooseX::Aliases;
 use MooseX::StrictConstructor;
 use Try::Tiny;
-use Business::CyberSource::Client;
+use Business::CyberSource::Client 0.006009;
 use MooseX::Types::CyberSource qw(AVSResult);
 use MooseX::Types::Moose qw(Bool HashRef Int Str);
 use MooseX::Types::Common::String qw(NonEmptySimpleStr);
 
 # ABSTRACT:  CyberSource Client object  for Business::OnlinePayment::CyberSource
-our $VERSION = '3.000008'; # VERSION
+our $VERSION = '3.000009'; # VERSION
 
 #### Subroutine Definitions ####
 
@@ -65,7 +65,7 @@ sub _authorize          {
 	}
 
 	my $request         = try {
-		use_module( $class )->new( $data );
+		load_class( $class )->new( $data );
 	}
 	catch {
 		$message = shift;
@@ -80,18 +80,16 @@ sub _authorize          {
 	try {
 		my $response = $self->run_transaction( $request );
 
-		if ( $response->is_accepted() ) {
+		if ( $response->is_accept() ) {
 			$self->is_success( 1 );
-
 		}
 		else {
 			$self->set_error_message( $response->reason_text() );
 		}
 
-		if ( $response->does(
-				'Business::CyberSource::Response::Role::Authorization'
-				)
-			) {
+  my $role       = 'Business::CyberSource::Response::Role::Authorization';
+
+		if ( $response->does( $role ) ) {
 			$self->authorization( $response->auth_code() )
 				if $response->has_auth_code;
 
@@ -105,9 +103,12 @@ sub _authorize          {
 		$self->_fill_fields( $response );
 	}
 	catch {
-		$message = shift;
+		my $e          = shift;
 
-		$self->set_error_message( "$message" );
+		# Rethrow if $e is not a string
+		$e->throw() if ref $e ne '';
+
+  $self->set_error_message( $e );
 	};
 
 	return $self->is_success();
@@ -136,7 +137,7 @@ sub capture            {
 	Exception::Base->throw( $message ) if $message;
 
 	my $request         = try {
-		use_module( 'Business::CyberSource::Request::Capture' )->new( $data );
+		load_class( 'Business::CyberSource::Request::Capture' )->new( $data );
 	}
 	catch {
 		$message          = shift;
@@ -151,7 +152,7 @@ sub capture            {
 	try {
 		my $response      = $self->run_transaction( $request );
 
-		if ( $response->is_success() ) {
+		if ( $response->is_accept() ) {
 			$self->is_success ( 1 );
 		}
 		else {
@@ -161,9 +162,12 @@ sub capture            {
 		$self->_fill_fields( $response );
 	}
 	catch {
-		$message       = shift;
+		my $e          = shift;
 
-		$self->set_error_message( "$message" );
+		# Rethrow if $e is not a string
+		$e->throw() if ref $e ne '';
+
+  $self->set_error_message( $e );
 	};
 
 	return $self->is_success();
@@ -194,7 +198,7 @@ sub credit             {
 	Exception::Base->throw( $message ) if $message;
 
 	my $request         = try {
-		use_module( 'Business::CyberSource::Request::Credit' )->new( $data );
+		load_class( 'Business::CyberSource::Request::Credit' )->new( $data );
 	}
 	catch {
 		$message          = shift;
@@ -209,7 +213,7 @@ sub credit             {
 	try {
 		my $response      = $self->run_transaction( $request );
 
-		if ( $response->is_success() ) {
+		if ( $response->is_accept() ) {
 			$self->is_success ( 1 );
 		}
 		else {
@@ -219,9 +223,12 @@ sub credit             {
 		$self->_fill_fields( $response );
 	}
 	catch {
-		$message       = shift;
+		my $e          = shift;
 
-		$self->set_error_message( "$message" );
+		# Rethrow if $e is not a string
+		$e->throw() if ref $e ne '';
+
+  $self->set_error_message( $e );
 	};
 
 	return $self->is_success();
@@ -250,7 +257,7 @@ sub auth_reversal {
 	Exception::Base->throw( $message ) if $message;
 
 	my $request         = try {
-		use_module( 'Business::CyberSource::Request::AuthReversal' )->new( $data );
+		load_class( 'Business::CyberSource::Request::AuthReversal' )->new( $data );
 	}
 	catch {
 		$self->set_error_message( "$_" );
@@ -261,7 +268,7 @@ sub auth_reversal {
 	try {
 		my $response        = $self->run_transaction( $request );
 
-		if ( $response->is_success() ) {
+		if ( $response->is_accept() ) {
 			$self->is_success ( 1 );
 		}
 		else {
@@ -271,9 +278,12 @@ sub auth_reversal {
 		$self->_fill_fields( $response );
 	}
 	catch {
-		$message       = shift;
+		my $e          = shift;
 
-		$self->set_error_message( "$message" );
+  # Rethrow if $e is not a string
+  $e->throw() if ref $e ne '';
+
+		$self->set_error_message( $e );
 	};
 
 	return $self->is_success();
@@ -338,9 +348,9 @@ sub _build_client { ## no critic ( Subroutines::ProhibitUnusedPrivateSubroutines
 	my $test                 = $self->test_transaction();
 
 	my $data                 = {
-		user => $username,
-		pass => $password,
-		test => $test,
+		username               => $username,
+		password               => $password,
+		production             => ! $test,
 	};
 
 	my $client               = Business::CyberSource::Client->new( $data );
@@ -625,7 +635,7 @@ Business::OnlinePayment::CyberSource::Client - CyberSource Client object  for Bu
 
 =head1 VERSION
 
-version 3.000008
+version 3.000009
 
 =head1 SYNOPSIS
 
@@ -893,7 +903,7 @@ Returns:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/business-onlinepayment-cybersource/issues
+https://github.com/hgdev/Business-OnlinePayment-CyberSource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -919,7 +929,7 @@ Peter Bowen <peter@bowenfamily.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Hostgator.com.
+This software is copyright (c) 2012 by Hostgator.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
